@@ -10,15 +10,10 @@ import typing
 class Wire:
     def __init__(self, strict: bool = True) -> None:
         self.router: Router = Router(strict=strict)
-        self.static: StaticFiles = None
 
     async def __call__(self, scope: dict, receive, send) -> None:
         req = Request(scope, receive, send)
         try:
-            if self.static is not None and req.path.startswith(self.static.route):
-                content, typ = self.static.provide(req.path)
-                resp = Response(content, headers={"content-type": typ})
-                await resp(scope, receive, send)
             func, params = await self.router.get_handler(req.path, req.method)
             if func:
                 if inspect.iscoroutinefunction(func):
@@ -29,8 +24,11 @@ class Wire:
                         elif type(response) == dict:
                             response = JsonResponse(response, 200)
                     await response(scope, receive, send)
+                if isinstance(func, StaticFiles):
+                    content, typ = func.provide(req.path)
+                    resp = Response(content, headers={"content-type": typ})
+                    await resp(scope, receive, send)
         except Exception as e:
-            print(e)
             response = HTMLResponse("Error occured", 404)
             await response(scope, receive, send)
 
@@ -68,13 +66,11 @@ class Wire:
 
     def mount(self, plugin: typing.Union[Group, StaticFiles], prefix: str = None):
         if isinstance(plugin, StaticFiles):
-            plugin.route = prefix
-            self.static = plugin
+            self.router.add_route(prefix + "/*filename",  plugin, "get")
             return True
         if not prefix.startswith("/"):
             raise Exception(f"Invalid prefix for router {plugin}")
         else:
             for route in plugin.routes:
                 self.router.add_route(prefix + route[0], route[1], route[2])
-            print(f"Mounted router: {plugin}")
             return True
