@@ -5,11 +5,8 @@ import os
 
 
 class StaticFiles:
-    def __init__(self, path: str, route_prefix: str = "/static") -> None:
+    def __init__(self, path: str) -> None:
         self.path = path
-        self.route = route_prefix
-        if not self.route.startswith("/"):
-            raise Exception("No proper route name")
 
     def provide(self, filepath: str):
         mime = MimeTypes()
